Creates or updates an index using data from already downloaded keywords.
proc_index(keywords, geo, index_name, backfill_from = NULL)A vector of keyword names comprising the index.
A character vector denoting geographic region.
The name given to the index.
Optional start date (YYYY-mm-dd). If supplied, the
daily series of each keyword is backfilled from this date before the regular
update (see proc_keyword_backfill_daily()). Use once after an outage.
This function assumes the data for all keywords exists. Then it proceeds to go through several steps:
updates all the keywords by downloading newest Google trends data.
combines monthly, weekly, and daily frequencies.
runs seasonal adjustment steps.
combines all the keywords into one index using principal components.
writes the produced index to a file
if (FALSE) { # \dontrun{
keywords <- c("Mango", "Zara", "H&M", "PKZ", "Blue Tomato", "Dosenbach", "Schuhe kaufen", "Ochsner Schuhe")
proc_index(keywords, "ch", "clothing")
} # }